@@ -4,6 +4,8 @@ from openfisca_tools.model_api import *
 import numpy as np
 from pathlib import Path
 
+from openfisca_us.typing import Formula
+
 ZIP_CODE_DATASET_PATH = (
     Path(__file__).parent.parent / "data" / "geography" / "zip_codes.csv.gz"
 )
@@ -90,3 +92,12 @@ def in_state(state):
         return population("state_code_str", period) == state
 
     return is_eligible
+
+
+def excess(of: str, over: str) -> Formula:
+    def formula(entity, period, parameters):
+        of_variable = add(entity, period, [of])
+        over_variable = add(entity, period, [over])
+        return max_(of_variable - over_variable, 0)
+
+    return formula
